@@ -5,7 +5,7 @@ import toolz
 from toolz import curried
 from toolz.curried import operator
 
-from gamla import functional
+from gamla import functional, functional_generic
 
 
 @toolz.curry
@@ -93,6 +93,20 @@ def get_connectivity_components(graph: Dict) -> Iterable[FrozenSet]:
 
 @toolz.curry
 def groupby_many(f, it):
+    """Return a mapping `{y: {x s.t. y \in f(x)}}, where `x \in it`. `
+
+    >>> names = ['alice', 'bob', 'charlie', 'dan', 'edith', 'frank']
+    >>> groupby_many(lambda name: (name[0], name[-1]), names)
+    {'a': frozenset({'alice'}),
+     'e': frozenset({'alice', 'charlie', 'edith'}),
+     'b': frozenset({'bob'}),
+     'c': frozenset({'charlie'}),
+     'd': frozenset({'dan'}),
+     'n': frozenset({'dan'}),
+     'h': frozenset({'edith'}),
+     'f': frozenset({'frank'}),
+     'k': frozenset({'frank'})}
+    """
     return toolz.pipe(
         it,
         curried.mapcat(
@@ -124,7 +138,7 @@ def _has_cycle(sourced, get_neighbors, visited, node):
     return toolz.pipe(
         node,
         get_neighbors,
-        functional.anymap(_has_cycle(sourced | {node}, get_neighbors, visited)),
+        functional_generic.anymap(_has_cycle(sourced | {node}, get_neighbors, visited)),
     )
 
 
